// import { useNavigate } from "react-router-dom";
import { useEffect, useState } from "react";
import Button from "../../base/button";
import styles from "./seat-layout.module.css";
import Seat from "../seat";
import { toast } from "react-toastify";

function SeatLayout({
  userId,
  seats,
  reservedSeats,
  selectedSeats,
  seatLimit,
  onClick,
}) {
  const [selectedseat, setSelectedSeat] = useState([...selectedSeats]);

  const handleSeats = (seat) => {
    if (!selectedseat?.includes(seat) && selectedseat.length < seatLimit) {
      setSelectedSeat([...selectedseat, seat]);
    } else if (selectedseat?.includes(seat)) {
      setSelectedSeat(selectedseat?.filter((e) => e != seat));
    } else {
      toast.info(`Cannot select seat more than ${seatLimit}`);
    }
  };
  useEffect(() => {
    setSelectedSeat([...selectedSeats]);
  }, [selectedSeats]);
  const handleConfirm = (e) => {
    e.preventDefault();
    if (!selectedseat.length || selectedseat.length < seatLimit) {
      toast.error(`please select upto ${seatLimit} `);
    } else {
      onClick({
        id: parseInt(userId),
        seats: selectedseat,
      });
    }
  };

  return (
    <>
      <div className={styles.container}>
        <h1>Choose Seats</h1>
        <div className="booking">
          <div className={styles.curve}>
            <div className={styles["curve-shadow"]}></div>
          </div>
          <div className={styles["seat-container"]}>
            {seats?.map((seat, i) => (
              <div key={i} className={styles.seat}>
                {seat?.map((e, i) => (
                  <div className={`${e === 0 ? styles["remove-seats"] : ""}`}>
                    <Seat
                      key={e}
                      seatNo={e}
                      onChange={() => handleSeats(e)}
                      status={
                        selectedseat?.includes(e)
                          ? "selected"
                          : reservedSeats?.includes(e)
                          ? "reserved"
                          : "available"
                      }
                    />
                  </div>
                ))}
              </div>
            ))}
          </div>
        </div>

        <Button onClick={handleConfirm}>Confirm</Button>
        <div className={styles["seat-status"]}>
          <div className={styles.selected}>
            <div></div>
            <p>Selected</p>
          </div>
          <div className={styles.reserved}>
            <div></div>
            <p>Reserved</p>
          </div>
          <div className={styles.available}>
            <div></div>
            <p>Available</p>
          </div>
        </div>
      </div>
    </>
  );
}
SeatLayout.defaultProps = {
  seats: [],
  reservedSeats: [],
  selectedSeats: [],
};
export default SeatLayout;
